Skip to content

auracomp 1.4

Choose a tag to compare

@Venomalia Venomalia released this 04 Mar 11:53
· 37 commits to main since this release

auracomp is a simple and fast command-line tool for compressing and decompressing files using the formats supported by AuroraLib.Compression.
It supports automatic format detection for decompression and a wide range of supported algorithms commonly used in video games.

Quick Use (Drag & Drop)

To quickly decompress a file, simply drag and drop it onto auracomp.exe.
The tool will automatically detect the format, and if successful, create an output file next to the input file with ~output appended to its name.

Usage

 -decompress    (-d)                   Decompress a file.
   -in          (-i)  <file path>      Input file path.
   -out         (-ou) <file path>      Output file path. [optional]
   -algo        (-a)  <name>           Algorithm/format name or MIME Type. [optional]
   -scan        (-sc)                  Scan input file for all valid compressed streams and extract them. [optional]
   -overwrite   (-o)                   Overwrite output file if already exists. [optional]
   -quiet       (-q)                   Suppress all output except errors. [optional]

 -compress      (-c)                   Compress a file using the specified algorithm.
   -in          (-i)  <file path>      Input file path.
   -out         (-ou) <file path>      Output file path. [optional]
   -algo        (-a)  <name>           Algorithm/format name or MIME Type
   -level       (-l)  <level>          CompressionLevel <Optimal, Fastest, NoCompression> [optional]
   -lookahead   (-la) <true|false>     Use LookAhead [optional, format-specific]
   -endian      (-e)  <Little|Big>     Byte order [optional, format-specific]
   -overwrite   (-o)                   Overwrite output file if already exists. [optional]
   -quiet       (-q)                   Suppress all output except errors. [optional]

 -mime          (-m)                   Try to recognize the file format used.
   -in          (-i)  <file path>      Input file path.

 -bruteforce    (-bf)                  Test all algorithms until one matches the expected decompressed size.
   -in          (-i)  <file path>      Input file path.
   -size        (-s)  <number>         Expected decompressed size in bytes.
   -offset      (-of) <number>         Start offset of compressed data in byte. [optional]
   -quiet       (-q)                   Suppress all output except errors. [optional]

 -help          (-h)                   Show this help.

example

Unpack a file using batch

auracomp -d -in "input.lz" -out "output.bin"

Compress a file using batch

auracomp -c -in "input.bin" -out "output.lz" -algo "Yaz0" -endian "Little"

Recognize a file using batch

auracomp -mime -in "input.bin"

Try to brute-force the compression algorithm and unpack the file:

auracomp -bruteforce -in "input.bin" -offset 4 -size 102400

Runtime Requirements

  • auracomp_net10
    Cross-platform build that requires the .NET 10 Runtime to be installed.

  • auracomp_net8
    Cross-platform build that requires the .NET 8 Runtime to be installed.

  • auracomp_net6
    Cross-platform build that requires the .NET 6 Runtime to be installed.

  • auracomp_net472
    Windows-only version that runs on machines with .NET Framework 4.7.2 or later. No extra runtime installation is needed on most Windows PCs.


What's Changed in auracomp 1.4

  • New -scan flag for decompression
    Added the ability to scan a file for multiple compressed streams and extract them automatically.
    Example usage:
auracomp -decompress -in "input.bin" -out "output_folder" -scan